@@ -2,10 +2,12 @@ from .args import Args, GeneratorArgs
 from .renderer import Renderer, PPrintRenderer, MultilineRenderer, ImshowRenderer
 from .callrenderer import CallRenderer, PPrintCallRenderer, IsliceRenderer
 
-from .exercise_function import ExerciseFunction, ExerciseFunctionNumpy
+from .exercise_function import (
+    ExerciseFunction, ExerciseFunctionNumpy, ExerciseFunctionPandas)
 from .exercise_regexp import ExerciseRegexp, ExerciseRegexpGroups
 from .exercise_generator import ExerciseGenerator
-from .exercise_class import ExerciseClass, ClassScenario, ClassExpression, ClassStatement
+from .exercise_class import (
+    ExerciseClass, ClassScenario, ClassExpression, ClassStatement)
 
 from .content import (TextContent, CodeContent, MathContent,
                       MarkdownContent, MarkdownMathContent)
